package com.hai.pay.channel.huipay.config;

import com.alibaba.fastjson.JSONObject;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.pay.WechatPayUtil;
import com.hai.common.utils.HttpsUtils;
import com.hai.config.CommonSysConst;
import com.hai.dao.HighPayRecordMapper;
import com.hai.entity.HighOrder;
import com.hai.entity.HighPayRecord;
import com.hai.order.utils.OrderUtil;
import com.hai.pay.channel.huipay.utils.SignatureUtil;
import com.hai.service.HighOrderService;
import com.hai.service.pay.PayRecordService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.SortedMap;
import java.util.TreeMap;

@Component
public class HuiConfig {

    @Resource
    private PayRecordService payRecordService;

    @Resource
    private HighOrderService highOrderService;

    private static Logger log = LoggerFactory.getLogger(HuiConfig.class);

    // 请求地址
    public final static String postUrl = "https://pay.dctpay.com/openApi/v1/";

    // 渝北区浩联物资经营部
    public final static String  hlMerNo = "2023090816465844909";
    public final static String  yFMerNo = "2023101109385455305";

    // 渝北区浩联物资经营部
    public final static String hlKey = "ZatCMLMSZxnkc2rk7dtpTORMLcKetcKt";
    public final static String yFKey = "plfJ6Ohgj4OmPblknuMzoSeT8cvI5dTR";

    public final static String hlSubAppid = "wx8d49e2f83025229d";

    /**
    * @Author Sum1Dream
    * @Name preorder
    * @Description // 发起支付
    * @Date 16:35 2023/9/13
    * @Param object
     * @return java.util.SortedMap<java.lang.Object,java.lang.Object>
    */
    public SortedMap<Object,Object> preorder(JSONObject object) throws Exception {
        object.put("merchantNo" , yFMerNo);
        object.put("subAppid" , hlSubAppid);
        object.put("sign" , SignatureUtil.createSign(object , yFKey));

        JSONObject jsonObject = HttpsUtils.doPost(postUrl + "trade/preorder", object, new HashMap<>());
        // 签名校验
        SortedMap<Object,Object> sortedMap = null;
        if (jsonObject.getString("return_code").equals("000000")) {

            JSONObject payParam = jsonObject.getJSONObject("return_data").getJSONObject("payParam");
            sortedMap = new TreeMap<>();
            sortedMap.put("appId", payParam.get("app_id"));
            sortedMap.put("nonceStr", payParam.get("nonce_str"));
            sortedMap.put("timeStamp", payParam.get("time_stamp"));
            sortedMap.put("signType", "MD5");
            sortedMap.put("package", payParam.get("package"));
            sortedMap.put("sign", payParam.get("pay_sign"));

            // 将支付请求存入支付纪录
            HighPayRecord payRecord = new HighPayRecord();
            payRecord.setBodyInfo(String.valueOf(payParam));
            payRecord.setResType(1);
            payRecord.setPayType(2);
            payRecord.setPayMoney(object.getBigDecimal("totalAmount"));
            payRecordService.addPayRecord(payRecord);

        } else {
            log.error("微信支付 -> 组装支付参数：支付信息错误");
            log.error("错误信息：" + jsonObject.getString("return_msg"));
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "无法支付，请稍后重新提交订单支付！");
        }

        return sortedMap;

    }

    /**
    * @Author Sum1Dream
    * @Name refund
    * @Description // 发起退款
    * @Date 16:35 2023/9/13
    * @Param orderNo
     * @return com.alibaba.fastjson.JSONObject
    */
    public JSONObject  refund(HighOrder order) throws Exception {

        JSONObject object = new JSONObject();
        object.put("merchantNo" , hlMerNo);
        object.put("outTradeNo" , order.getOrderNo());
        object.put("refundTradeNo" , OrderUtil.generateRefundOrderNo());
        object.put("refundAmount" , order.getPayRealPrice());
        object.put("sign" , SignatureUtil.createSign(object , hlKey));

        return HttpsUtils.doPost(postUrl + "trade/refund", object, new HashMap<>());

    }


}
